@@ -302,12 +302,12 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
     # ensure yarn installs all build tools
         local("pwd")
-        local('YARN_CACHE_FOLDER %s yarn --production=false --no-progress --non-interactive install' % yarn_cache)
+        local('YARN_CACHE_FOLDER=%s yarn --production=false --no-progress --non-interactive install' % yarn_cache)
 
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('YARN_CACHE_FOLDER %s yarn build %s %s' % (yarne_cache, options, ngApp))
+            local('YARN_CACHE_FOLDER=%s yarn build %s %s' % (yarne_cache, options, ngApp))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
